@@ -6,16 +6,16 @@ function d3_set_attr(selection, name, value) {
   selection.attr(name, value);
 }
 
-function select_data_id_single(selection, js_varname) {
+function select_data_id_single(selection, js_varname, svg_id) {
   selection.on("click", function(d,i) {
+    d3.selectAll(svg_id + ' *[data-id]').classed('selected_', false);
     var dataid = d3.select(this).attr("data-id");
     if( window[js_varname][0] == dataid ){
       window[js_varname] = [];
-      d3.select(this).classed('selected_', true);
     }
     else {
       window[js_varname] = [dataid];
-      d3.select(this).classed('selected_', false);
+      d3.select(this).classed('selected_', true);
     }
     Shiny.onInputChange(js_varname, window[js_varname]);
   });
@@ -50,15 +50,15 @@ HTMLWidgets.widget({
 
     return {
       renderValue: function(x) {
-        el.innerHTML = x.html ;
+        el.innerHTML = x.html;
         var fn = Function(x.code);
         fn();
 
         var svg_id = '#svg_' + x.canvas_id;
         var selected_id = el.id + '_selected';
-
+        window[el.id + '_canvas'] = '#svg_' + x.canvas_id;
         d3.select(el).attr("style", "text-align:center;");
-
+        window[el.id + '_id'] = svg_id;
         var tooltip_class = "tooltip" + x.data_id_class;
 
         // generate css elements
@@ -66,7 +66,7 @@ HTMLWidgets.widget({
           x.data_id_class +  ":hover{" + x.hover_css + "}";
 
         var tooltip_css = "div." + tooltip_class +
-          " {position:absolute;pointer-events:none;";
+          " {position:absolute;pointer-events:none;z-index:999;";
         tooltip_css += x.tooltip_extra_css;
         tooltip_css += "}";
 
@@ -85,27 +85,18 @@ HTMLWidgets.widget({
         sel_data_id.call(d3_set_attr, "class", x.data_id_class);
 
         if( HTMLWidgets.shinyMode ){
-          window[el.id + "_selected"] = [];
+
+          if( !( el.id + "_selected" in window ) )
+            window[el.id + "_selected"] = [];
           if( x.selection_type == "single")
-            sel_data_id.call(select_data_id_single, selected_id);
+            sel_data_id.call(select_data_id_single, selected_id, svg_id);
           else if( x.selection_type == "multiple")
             sel_data_id.call(select_data_id_multiple, selected_id);
 
-          if( x.selection_type != "none" ){
-            Shiny.addCustomMessageHandler(el.id + "_set",
-              function(message) {
-                var varname = el.id + "_selected";
-                var variable_ = window[varname];
-                d3.selectAll(variable_)
-                  .each(function(d, i) {
-                    d3.selectAll('#svg_' + x.canvas_id + ' *[data-id="'+ variable_[i] + '"]')
-                      .classed('selected_', false);
-                  });
-                window[varname] = message;
-                Shiny.onInputChange(varname, window[varname]);
-              }
-            );
-          }
+          d3.selectAll(window[el.id + "_selected"]).each(function(d, i) {
+            d3.selectAll(svg_id + ' *[data-id=\"'+ window[el.id + "_selected"][i] + '\"]').classed('selected_', true);
+            });
+
         }
 
         var sel_tooltiped = d3.selectAll(svg_id + ' *[title]');
@@ -123,36 +114,25 @@ HTMLWidgets.widget({
                     .style("opacity", 0);
             });
 
-        window[el.id + "_maxwidth"] = width;
-        window[el.id + "_maxheight"] = height;
         d3.select('#svg_' + x.canvas_id)
-          .attr("preserveAspectRatio", "xMidYMid meet")
-          .attr("width", width).attr("height", null);
-
+          .attr("preserveAspectRatio", "xMinYMin meet")
+          .classed("svg-content-responsive", true)
+          .attr("width", "100%").attr("height", "100%");
         if(x.zoompan===true) {
           var zoom_l = d3.behavior.zoom().scaleExtent([1, x.zoom_max]).on("zoom", zoom_h);
           zoom_l(d3.select('#svg_' + x.canvas_id + ' g'));
         }
+        d3.select(el)
+            .style( "position", "relative")
+            .style( "padding-bottom", x.padding_bottom)
+            .style( "vertical-align", "top")
+            .style( "margin", "auto")
+            .style( "overflow", "hidden")
+            .style( "width", x.width);
       },
 
       resize: function(width, height) {
-        var svg_elt = d3.select(el).select("svg");
-        var maxw = window[el.id + "_maxwidth"];
-        var maxh = window[el.id + "_maxheight"];
 
-        if( !HTMLWidgets.viewerMode && maxw < width ){
-          width = maxw;
-        }
-
-        if( !HTMLWidgets.viewerMode && maxh < height ){
-          height = maxh;
-        } else if( HTMLWidgets.viewerMode ){
-          height = null;
-        }
-
-        svg_elt
-          .attr("width", width)
-          .attr("height", null);
       }
 
     };
